
## CATO-CLI - mutation.policy.antiMalwareFileHash.addRule:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.policy.antiMalwareFileHash.addRule) for documentation on this operation.

### Usage for mutation.policy.antiMalwareFileHash.addRule:

```bash
catocli mutation policy antiMalwareFileHash addRule -h

catocli mutation policy antiMalwareFileHash addRule <json>

catocli mutation policy antiMalwareFileHash addRule --json-file mutation.policy.antiMalwareFileHash.addRule.json

catocli mutation policy antiMalwareFileHash addRule '{"antiMalwareFileHashAddRuleInput":{"antiMalwareFileHashAddRuleDataInput":{"action":"BLOCK","description":"string","enabled":true,"expirationDate":"example_value","fileName":"string","name":"string","sha256":"example_value"},"policyRulePositionInput":{"position":"AFTER_RULE","ref":"id"}},"antiMalwareFileHashPolicyMutationInput":{"policyMutationRevisionInput":{"id":"id"}}}'

catocli mutation policy antiMalwareFileHash addRule '{
    "antiMalwareFileHashAddRuleInput": {
        "antiMalwareFileHashAddRuleDataInput": {
            "action": "BLOCK",
            "description": "string",
            "enabled": true,
            "expirationDate": "example_value",
            "fileName": "string",
            "name": "string",
            "sha256": "example_value"
        },
        "policyRulePositionInput": {
            "position": "AFTER_RULE",
            "ref": "id"
        }
    },
    "antiMalwareFileHashPolicyMutationInput": {
        "policyMutationRevisionInput": {
            "id": "id"
        }
    }
}'
```

#### Operation Arguments for mutation.policy.antiMalwareFileHash.addRule ####

`accountId` [ID] - (required) N/A    
`antiMalwareFileHashAddRuleInput` [AntiMalwareFileHashAddRuleInput] - (required) N/A    
`antiMalwareFileHashPolicyMutationInput` [AntiMalwareFileHashPolicyMutationInput] - (required) N/A    
